High Performance Computing MCQs with answers Page - 14

Here, you will find a collection of MCQ questions on High Performance Computing. Go through these questions to enhance your preparation for upcoming examinations and interviews.

To check the correct answer, simply click the View Answer button provided for each question.

Have your own questions to contribute? Click the button below to share your MCQs with others!

+ Add Question

A

Admin • 833.24K Points
Coach

Q. The CUDA architecture consists of --------- for parallel computing kernels and functions.

  • (A) risc instruction set architecture
  • (B) cisc instruction set architecture
  • (C) zisc instruction set architecture
  • (D) ptx instruction set architecture

A

Admin • 833.24K Points
Coach

Q. CUDA stands for --------, designed by NVIDIA.

  • (A) common union discrete architecture
  • (B) complex unidentified device architecture
  • (C) compute unified device architecture
  • (D) complex unstructured distributed architecture

A

Admin • 833.24K Points
Coach

Q. The host processor spawns multithread tasks (or kernels as they are known in CUDA) onto the GPU device. State true or false.

  • (A) true
  • (B) false
  • (C) ---
  • (D) ---

A

Admin • 833.24K Points
Coach

Q. The NVIDIA G80 is a ---- CUDA core device, the NVIDIA G200 is a ---- CUDA core device, and the NVIDIA Fermi is a ---- CUDA core device.

  • (A) 128, 256, 512
  • (B) 32, 64, 128
  • (C) 64, 128, 256
  • (D) 256, 512, 1024

A

Admin • 833.24K Points
Coach

Q. NVIDIA 8-series GPUs offer -------- .

  • (A) 50-200 gflops
  • (B) 200-400 gflops
  • (C) 400-800 gflops
  • (D) 800-1000 gflops

A

Admin • 833.24K Points
Coach

Q. IADD, IMUL24, IMAD24, IMIN, IMAX are ----------- supported by Scalar Processors of NVIDIA GPU.

  • (A) 32-bit ieee floating point instructions
  • (B) 32-bit integer instructions
  • (C) both
  • (D) none of the above

A

Admin • 833.24K Points
Coach

Q. CUDA Hardware programming model supports:
a) fully generally data-parallel archtecture;
b) General thread launch;
c) Global load-store;
d) Parallel data cache;
e) Scalar architecture;
f) Integers, bit operation

  • (A) a,c,d,f
  • (B) b,c,d,e
  • (C) a,d,e,f
  • (D) a,b,c,d,e,f

A

Admin • 833.24K Points
Coach

Q. In CUDA memory model there are following memory types available:
a) Registers;
b) Local Memory;
c) Shared Memory;
d) Global Memory;
e) Constant Memory;
f) Texture Memory.

  • (A) a, b, d, f
  • (B) a, c, d, e, f
  • (C) a, b, c, d, e, f
  • (D) b, c, e, f

A

Admin • 833.24K Points
Coach

Q. What is the equivalent of general C program with CUDA C: int main(void) { printf("Hello, World!
"); return 0; }

  • (A) int main ( void ) { kernel <<<1,1>>>(); printf("hello, world!\n"); return 0; }
  • (B) __global__ void kernel( void ) { } int main ( void ) { kernel <<<1,1>>>(); printf("hello, world!\n"); return 0; }
  • (C) __global__ void kernel( void ) { kernel <<<1,1>>>(); printf("hello, world!\n"); return 0; }
  • (D) __global__ int main ( void ) { kernel <<<1,1>>>(); printf("hello, world!\n"); return 0; }

A

Admin • 833.24K Points
Coach

Q. Which function runs on Device (i.e. GPU): a) __global__ void kernel (void ) { } b) int main ( void ) { ... return 0; }

  • (A) a
  • (B) b
  • (C) both a,b
  • (D) ---

Add MCQ in this Category

If you want to share an MCQ question in this category, it's a great idea! It will be helpful for many other students using this website.

Share Your MCQ